Aglyph API reference — Aglyph 3.0.0 documentation

# Aglyph API reference

Release: | 3.0.0

The Aglyph API consists of a single top-level package (`aglyph`) along with several modules and subpackages, as listed below.

- `aglyph` — Dependency Injection for Python
- `aglyph.assembler` — The Aglyph component assembler
- `aglyph.component` — Defining components and their dependencies
- `aglyph.context` — Defining component contexts
- `aglyph.integration.cherrypy` — Integrating Aglyph with CherryPy